DropHusk

Trait DropHusk 

pub unsafe trait DropHusk: HasPlace {
    // Required method
    unsafe fn drop_husk(ptr: *mut Self);
}
Clean up a pointer whose contained place has been moved out of/dropped.

Required Methods

unsafe fn drop_husk(ptr: *mut Self)

Drop the pointer but not the contents of the place (borrowck takes care of that).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors